@@ -17,14 +17,14 @@ import (
 	"github.com/liamg/tml"
 )
 
-func output(cmd *cobra.Command, baseFilename string, formats []string, dir string, results []scan.Result, metrics scanner.Metrics) error {
+func output(cmd *cobra.Command, baseFilename string, formats []string, fsRoot, dir string, results []scan.Result, metrics scanner.Metrics) error {
 	if baseFilename == "" && len(formats) > 1 {
 		return fmt.Errorf("you must specify a base output filename with --out if you want to use multiple formats")
 	}
 
 	var files []string
 	for _, format := range formats {
-		if filename, err := outputFormat(cmd.OutOrStdout(), len(formats) > 1, baseFilename, format, dir, results, metrics); err != nil {
+		if filename, err := outputFormat(cmd.OutOrStdout(), len(formats) > 1, baseFilename, format, fsRoot, dir, results, metrics); err != nil {
 			return err
 		} else if filename != "" {
 			files = append(files, filename)
@@ -66,41 +66,38 @@ func gatherLinks(result scan.Result) []string {
 	return append(docsLink, links...)
 }
 
-func outputFormat(w io.Writer, addExtension bool, baseFilename string, format string, dir string, results scan.Results, metrics scanner.Metrics) (string, error) {
+func outputFormat(w io.Writer, addExtension bool, baseFilename, format, fsRoot, dir string, results scan.Results, metrics scanner.Metrics) (string, error) {
 
 	factory := formatters.New().
 		WithDebugEnabled(debug).
 		WithColoursEnabled(!disableColours).
 		WithGroupingEnabled(!disableGrouping).
 		WithLinksFunc(gatherLinks).
+		WithFSRoot(fsRoot).
 		WithBaseDir(dir).
 		WithMetricsEnabled(!conciseOutput).
 		WithIncludeIgnored(includeIgnored).
 		WithIncludePassed(includePassed)
 
 	var alsoStdout bool
-	var makeRelative bool
+	makeRelative := true
 
 	switch strings.ToLower(format) {
 	case "lovely", "default":
 		alsoStdout = true
 		factory.WithCustomFormatterFunc(formatter.DefaultWithMetrics(metrics, conciseOutput))
 	case "json":
-		makeRelative = true
 		factory.AsJSON()
+		makeRelative = false
 	case "csv":
-		makeRelative = true
 		factory.AsCSV()
 	case "checkstyle":
-		makeRelative = true
 		factory.AsCheckStyle()
 	case "junit":
-		makeRelative = true
 		factory.AsJUnit()
 	case "text":
 		factory.WithCustomFormatterFunc(formatter.DefaultWithMetrics(metrics, conciseOutput)).WithColoursEnabled(false)
 	case "sarif":
-		makeRelative = true
 		factory.AsSARIF()
 	case "gif":
 		factory.WithCustomFormatterFunc(formatter.GifWithMetrics(metrics))
@@ -108,9 +105,7 @@ func outputFormat(w io.Writer, addExtension bool, baseFilename string, format st
 		return "", fmt.Errorf("invalid format specified: '%s'", format)
 	}
 
-	if makeRelative {
-		results.SetRelativeTo(dir)
-	}
+	factory.WithRelativePaths(makeRelative)
 
 	var outputPath string
 	if baseFilename != "" {
