@@ -18,7 +18,7 @@ func prerun(cmd *cobra.Command, args []string) error {
 	cmd.SilenceUsage = true
 
 	// disable colour if running on windows - colour formatting doesn't work
-	if disableColours || runtime.GOOS == "windows" {
+	if disableColours || (runtime.GOOS == "windows" && os.Getenv("TERM") == "") {
 		tml.DisableFormatting()
 	} else {
 		tml.EnableFormatting()
